@@ -1,3 +1,19 @@
+"""
+In this tool we use the Model View Controller (MVC) design pattern.
+The MCV can be considered an approach to distinguish between the data model, processing control and the user interface.
+It neatly separates the graphical interface displayed to the user from the code that manages the user actions.
+
+In this file we define the 'Boxmanager_view_ABC' which is the generic representation of the view
+
+Here we define the structure of the view and implement all the function which call the GUI framework and wrapper libs,
+at the time of writing (24.1.22) we are using pyqt5 (the try-except statment in the import step will be removed in the future).
+
+In this way if in the future we want to change the wrapper libs we have 'only to change the syntax in this file and in
+'helper_GUI.py' without changing the logic of the whole view
+
+
+"""
+
 try:
     QT = 4
     import PyQt4.QtGui as QtG
@@ -287,6 +303,10 @@ class Boxmanager_view_ABC(QtG.QMainWindow):
 
     @abstractmethod
     def create_tab_visualization(self)->None:
+        """
+        It creates the 'visualization' tab used for changing the visualization of the particles/filaments
+        this tab is created at the run.
+        """
         line_counter = 1
         layout = QtG.QGridLayout()
 
@@ -327,6 +347,10 @@ class Boxmanager_view_ABC(QtG.QMainWindow):
 
     @abstractmethod
     def create_tab_thresholding(self)->None:
+        """
+        It creates the 'thresholding' tab used for filtering the particles/filaments got via Cryolo
+        this tab is created at the run. Its variables will be unblur after after loading cbox traced/untraced file
+        """
         line_counter = 1
         layout = QtG.QGridLayout()
 
@@ -404,8 +428,8 @@ class Boxmanager_view_ABC(QtG.QMainWindow):
     def create_tab_tracing(self)->None:
         """
         this tab is not created at the run of the GUI but it will appear automatically after loading cbox untraced file
+        At the time of writing (24.1.22) this option is enable only for the particle
         """
-
         # when it ll be usable we ll let blurred some options in not filament case
         self.tabs.addTab(self.tab_tracing, "Tracing")
         line_counter = 1
@@ -593,6 +617,9 @@ class Boxmanager_view_ABC(QtG.QMainWindow):
 
     @abstractmethod
     def slider_pressed(self)->None:
+        """
+        Set the vars which manage the pressing of the sliders
+        """
         self.is_slider_pressed = True
         self.is_updating_params = True
 
@@ -872,14 +899,23 @@ class Boxmanager_view_ABC(QtG.QMainWindow):
 
     @abstractmethod
     def display_default_params(self):
+        """
+        Set the default vars as at the start
+        """
         helper_GUI.display_default_params(view=self)
 
     @abstractmethod
     def tracing_tab_blurring(self, is_enable:bool, has_filament:bool):
+        """
+        Blur the tracing table, it happens when the code is elaborating the tracing step
+        """
         helper_GUI.tracing_tab_blurring(view=self, is_enable=is_enable, has_filament=has_filament)
 
     @abstractmethod
     def blur_estimated_size(self):
+        """
+        Blur the 'estimated size'
+        """
         self.use_estimated_size_checkbox.setEnabled(False)
         self.use_estimated_size_label.setEnabled(False)
 
@@ -905,26 +941,53 @@ class Boxmanager_view_ABC(QtG.QMainWindow):
 
     @abstractmethod
     def apply_to_all_the_tomo_question(self, name_param:str)->int:
+        """
+        Apply the changes to all the tomos
+        :param name_param: name of the parameter is changed
+        """
         return helper_GUI.apply_to_all_the_tomo_question(self,name_param=name_param)
 
     @abstractmethod
     def err_message(self, msg:str)->None:
+        """
+        Show an error message
+        :param msg: error message to show
+        """
         helper_GUI.err_message(self,msg=msg)
 
     @abstractmethod
     def qt_esixting_folder(self, msg:str)->str:
+        """
+        shows the pop up question message and returns the inserted answer
+        :param msg: message to show
+        """
         return helper_GUI.qt_esixting_folder(self,msg=msg)
 
     @abstractmethod
     def qtmessage(self, msg:str,has_cancel:bool)->int:
+        """
+        shows the pop up question message and returns the inserted answer
+        :param msg: message to show
+        :param has_cancel: If True it has 'QtG.QMessageBox.Cancel' instead of 'QtG.QMessageBox.No'
+        """
         return helper_GUI.qtmessage(self,msg=msg, has_cancel=has_cancel)
 
     @abstractmethod
     def get_selected_folder(self, unsaved_changes:bool)->str:
+        """
+        Set image_folder_path. It is selected by the user via GUI
+        :param unsaved_changes:
+        :return The selected folder
+        """
         return helper_GUI.get_selected_folder(self,unsaved_changes=unsaved_changes)
 
     @abstractmethod
     def get_selected_file(self, unsaved_changes:bool)->str:
+        """
+        Set current_image_path. It is selected by the user via GUI
+        :param unsaved_changes:
+        :return The selected file
+        """
         return helper_GUI.get_selected_file(self,unsaved_changes=unsaved_changes)
 
     @abstractmethod
