@@ -1,9 +1,12 @@
+import typing
+
 from cryoloBM.bmtool import BMTool
 import argparse
 from argparse import ArgumentParser
 import os
 from pyStarDB import sp_pystardb as star
 import pandas as pd
+from glob import glob
 
 class MakeAutopickStar(BMTool):
 
@@ -27,7 +30,7 @@ class MakeAutopickStar(BMTool):
             "--micrographs",
             required=True,
             nargs='+',
-            help="Folder to micrographs",
+            help="Path to micrograph files. Can be folder or a wildmask. In case of a wildmask, enclose the argument in single quotes like -c 'path/to/mics/*.mrc'.",
         )
 
         autopick_required_group.add_argument(
@@ -35,7 +38,7 @@ class MakeAutopickStar(BMTool):
             "--coordinates",
             required=True,
             nargs='+',
-            help="Folder to micrographs",
+            help="Path to STAR files. Can be folder or a wildmask. In case of a wildmask, enclose the argument in single quotes like -c 'path/to/star/*.star'.",
         )
 
         autopick_required_group.add_argument(
@@ -45,9 +48,23 @@ class MakeAutopickStar(BMTool):
             help="Output folder where to write the autopick.star.",
         )
 
+    @staticmethod
+    def get_paths(paths: typing.List[str], fallback_wildcard: str):
+        files = paths
+        if len(paths)==1:
+            if os.path.isdir(paths[0]):
+                path_for_glob = os.path.join(paths[0], fallback_wildcard)
+            else:
+                path_for_glob = paths[0]
+            files = glob(path_for_glob)
+        return files
+
     def run(self, args):
-        micrographs = args.micrographs
-        coordinates = args.coordinates
+        micrographs = MakeAutopickStar.get_paths(args.micrographs,"*.mrc")
+        coordinates = MakeAutopickStar.get_paths(args.coordinates,"*.star")
+
+
+
 
         micrographs_filename = [os.path.splitext(os.path.basename(m))[0] for m in micrographs]
         coordinates_filename = [os.path.splitext(os.path.basename(m))[0] for m in coordinates]
@@ -65,6 +82,7 @@ class MakeAutopickStar(BMTool):
         data_dict = {'_rlnMicrographName': micrographs_mapped, '_rlnMicrographCoordinates': coordinates_mapped}
         data = pd.DataFrame(data_dict)
         os.makedirs(args.output,exist_ok=True)
+        print(os.path.join(args.output,"autopick.star"))
         new_sfile = star.StarFile(os.path.join(args.output,"autopick.star"))
         new_sfile.update('coordinate_files', data, loop=True)
         new_sfile.write_star_file(overwrite=True)
