@@ -7,6 +7,7 @@ import copy
 import re
 from cryolo import CoordsIO, utils
 from cryoloBM.bmtool import BMTool
+import cryoloBM.boxmanager_tools as btools
 from argparse import ArgumentParser
 import argparse
 
@@ -58,27 +59,7 @@ class ScaleTool(BMTool):
             scale_factor=args.scale
         )
 
-TYPE_CBOX=0
-TYPE_COORDS=1
-TYPE_EMAN_BOX=2
-TYPE_EMAN_BOX_3D=3
-TYPE_EMAN_HELICON=4
-TYPE_EMAN_START_END=5
-TYPE_RELION_STAR=6
 
-def get_file_type(path):
-    from cryolo import CoordsIO
-    if CoordsIO.is_eman1_filament_start_end(path):
-        return TYPE_EMAN_START_END
-    if CoordsIO.is_eman1_helicon(path):
-        return TYPE_EMAN_HELICON
-    if CoordsIO.is_star_filament_file(path):
-        return TYPE_RELION_STAR
-    if path.endswith(".coords"):
-        return TYPE_COORDS
-    if path.endswith(".cbox"):
-        return TYPE_CBOX
-    return -1
 
 def read_eman1_helicon_micrgraph_name(path):
     with open(path, "r") as csvfile:
@@ -127,18 +108,18 @@ def scale(input_path,
         files = glob.glob(path)
 
     for pth in files:
-        if get_file_type(pth) == TYPE_COORDS:
+        if btools.get_file_type(pth) == btools.TYPE_COORDS:
             coords = [np.atleast_2d(np.genfromtxt(pth))]
             scaled_coords = scale_coords(coords, scale_factor)
             output_file_path = os.path.join(output_path,os.path.basename(pth))
             write_coords_file(output_file_path,scaled_coords[0])
-        elif get_file_type(pth) == TYPE_EMAN_HELICON:
+        elif btools.get_file_type(pth) == btools.TYPE_EMAN_HELICON:
             filaments_per_file = CoordsIO.read_eman1_helicon(pth)
             mic_name = read_eman1_helicon_micrgraph_name(pth)
             scaled_filaments = scale_filament(filaments_per_file,scale_factor)
             output_file_path = os.path.join(output_path, os.path.basename(pth))
             CoordsIO.write_eman1_helicon(scaled_filaments, output_file_path, mic_name)
-        elif get_file_type(pth) == TYPE_CBOX:
+        elif btools.get_file_type(pth) == btools.TYPE_CBOX:
             coords = CoordsIO.read_cbox_boxfile(pth)
             addinclude = CoordsIO.read_cbox_include_list(pth)
             scaled_coords = []
